@@ -1,8 +1,8 @@
-#' Returns the global optimum and its value.
+#' Returns the global optimum and its value
 #'
 #' @template arg_smoof_function
 #' @return [\code{list}] List containing the following entries:
-#' \itemize{
+#' \describe{
 #'   \item{param [\code{list}]}{Named list of parameter value(s).}
 #'   \item{value [\code{numeric(1)}]}{Optimal value.}
 #'   \item{is.minimum [\code{logical(1)}]}{Is the global optimum a minimum or maximum?}
@@ -24,7 +24,7 @@ getGlobalOptimum.smoof_single_objective_function = function(fn) {
 
 #' @export
 getGlobalOptimum.smoof_multi_objective_function = function(fn) {
-  stopf("No global optimum available for multi-objective function.")
+  BBmisc::stopf("No global optimum available for multi-objective function.")
 }
 
 #' @export
