@@ -1,7 +1,8 @@
-#' Determine the number of parameters.
+#' Determines the number of parameters
 #'
 #' @template arg_smoof_function
 #' @return [\code{integer(1)}]
+#'  The number of parameters.
 #' @export
 getNumberOfParameters = function(fn) {
   UseMethod("getNumberOfParameters")
@@ -9,7 +10,7 @@ getNumberOfParameters = function(fn) {
 
 #' @export
 getNumberOfParameters.smoof_function = function(fn) {
-  return(sum(getParamLengths(getParamSet(fn))))
+  return(sum(ParamHelpers::getParamLengths(getParamSet(fn))))
 }
 
 #' @export
