@@ -1,7 +1,8 @@
-#' Checks whether the objective function has constraints.
+#' Checks whether the objective function has constraints
 #'
 #' @template arg_smoof_function
 #' @return [\code{logical(1)}]
+#'  \code{TRUE} if the function has constraints, \code{FALSE} otherwise.
 #' @export
 hasConstraints = function(fn) {
   UseMethod("hasConstraints")
@@ -18,7 +19,7 @@ hasConstraints.smoof_wrapped_function = function(fn) {
   return(hasBoxConstraints(fn) || hasOtherConstraints(fn))
 }
 
-#' Checks whether the objective function has box constraints.
+#' Checks whether the objective function has box constraints
 #'
 #' @template arg_smoof_function
 #' @return [\code{logical(1)}]
@@ -29,15 +30,15 @@ hasBoxConstraints = function(fn) {
 
 #' @export
 hasBoxConstraints.smoof_function = function(fn) {
-  return(hasFiniteBoxConstraints(getParamSet(fn)))
+  return(ParamHelpers::hasFiniteBoxConstraints(getParamSet(fn)))
 }
 
 #' @export
 hasBoxConstraints.smoof_wrapped_function = function(fn) {
-  return(hasFiniteBoxConstraints(getParamSet(getWrappedFunction(fn))))
+  return(ParamHelpers::hasFiniteBoxConstraints(getParamSet(getWrappedFunction(fn))))
 }
 
-#' Checks whether the objective function has other constraints.
+#' Checks whether the objective function has other constraints
 #'
 #' @template arg_smoof_function
 #' @return [\code{logical(1)}]
