@@ -1,4 +1,4 @@
-#' Generator for multi-objective target functions.
+#' Generator for multi-objective target functions
 #'
 #' @template arg_name
 #' @template arg_id
@@ -17,7 +17,7 @@
 #' @template arg_vectorized
 #' @template arg_constraint_fn
 #' @param ref.point [\code{numeric}]\cr
-#'   Optional reference point in the objective space, e.g., for hypervolume computation.
+#'   Optional reference point in the objective space, e.g., for hyper-volume computation.
 #' @return [\code{function}] Target function with additional stuff attached as attributes.
 #' @examples
 #' fn = makeMultiObjectiveFunction(
@@ -50,10 +50,10 @@ makeMultiObjectiveFunction = function(
   )
 
   if (!is.null(ref.point)) {
-    assertNumeric(ref.point, len = n.objectives, any.missing = FALSE, all.missing = FALSE)
+    checkmate::assertNumeric(ref.point, len = n.objectives, any.missing = FALSE, all.missing = FALSE)
   }
 
-  smoof.fn = setAttribute(smoof.fn, "ref.point", ref.point)
+  smoof.fn = BBmisc::setAttribute(smoof.fn, "ref.point", ref.point)
   class(smoof.fn) = c("smoof_multi_objective_function", class(smoof.fn))
 
   return(smoof.fn)
