@@ -2,18 +2,20 @@
 #' BK1 function generator
 #'
 #' @description
-#' ...
+#' Generates the BK1 function, a multi-objective optimization test function. The BK1 function
+#' is commonly used in benchmarking studies for evaluating the performance of optimization algorithms.
 #'
 #' @references
 #' ...
 #'
 #' @return [\code{smoof_multi_objective_function}]
+#'  Returns an instance of the BK1 function as a \code{smoof_multi_objective_function} object.
 #' @export
 makeBK1Function = function() {
 
   # C++ implementation
   fn = function(x) {
-    assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
+    checkNumericInput(x, 2L)
     return(.Call("mof_bk1", x))
   }
 
@@ -22,7 +24,7 @@ makeBK1Function = function() {
     id = "bk1",
     description = "BK1 function",
     fn = fn,
-    par.set =  makeNumericParamSet(
+    par.set =  ParamHelpers::makeNumericParamSet(
       len = 2L,
       id = "x",
       lower = rep(-5, 2L),
