@@ -1,5 +1,5 @@
 #' @title
-#' MOP1 function generator.
+#' MOP1 function generator
 #'
 #' @description
 #' MOP1 function from Van Valedhuizen's test suite.
@@ -10,13 +10,14 @@
 #' Applications, J. J. Grenfenstett, Ed., 1985, pp. 93-100.
 #'
 #' @return [\code{smoof_multi_objective_function}]
+#'  Returns an instance of the MOP1 function as a \code{smoof_multi_objective_function} object.
 #' @export
 makeMOP1Function = function() {
 
   # C implementation
   fn = function(x) {
-    assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
-    return(.Call("mof_MOP1", x))
+    checkNumericInput(x, 2L)
+    .Call("mof_MOP1", x)
   }
 
   makeMultiObjectiveFunction(
@@ -24,7 +25,7 @@ makeMOP1Function = function() {
     id = "MOP1",
     description = "MOP1 function",
     fn = fn,
-    par.set =  makeNumericParamSet(
+    par.set =  ParamHelpers::makeNumericParamSet(
       len = 2L,
       id = "x",
       lower = -1e5,
