@@ -1,5 +1,5 @@
 #' @title
-#' MOP5 function generator.
+#' MOP5 function generator
 #'
 #' @description
 #' MOP5 function from Van Valedhuizen's test suite.
@@ -8,18 +8,19 @@
 #' Original box constraints where \eqn{[-3, 3]}.
 #'
 #' @references
-#' R. Viennet, C. Fonteix, and I. Marc, "Multicriteria optimization using a
+#' R. Viennet, C. Fonteix, and I. Marc, "Multi criteria optimization using a
 #' genetic algorithm for determining a Pareto set," Int. J. Syst. Sci., vol. 27,
 #' no. 2, pp. 255-260, 1996
 #'
 #' @return [\code{smoof_multi_objective_function}]
+#'  Returns an instance of the MOP5 function as a \code{smoof_multi_objective_function} object.
 #' @export
 makeMOP5Function = function() {
 
   # C implementation
   fn = function(x) {
-    assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
-    return(.Call("mof_MOP5", x))
+    checkNumericInput(x, 2L)
+    .Call("mof_MOP5", x)
   }
 
   makeMultiObjectiveFunction(
@@ -27,7 +28,7 @@ makeMOP5Function = function() {
     id = sprintf("MOP5-%id-%io", 2L, 3L),
     description = "MOP5 function",
     fn = fn,
-    par.set =  makeNumericParamSet(
+    par.set =  ParamHelpers::makeNumericParamSet(
       len = 2L,
       id = "x",
       lower = rep(-30, 2L),
