@@ -34,10 +34,11 @@
 #' @param n.objectives [\code{integer(1)}]\cr
 #'   Number of objectives.
 #' @return [\code{smoof_multi_objective_function}]
+#'  Returns an instance of the DTLZ1 family as a \code{smoof_multi_objective_function} object.
 #' @export
 makeDTLZ1Function = function(dimensions, n.objectives) {
-  assertInt(n.objectives, lower = 2L)
-  assertInt(dimensions, lower = n.objectives)
+  checkmate::assertInt(n.objectives, lower = 2L)
+  checkmate::assertInt(dimensions, lower = n.objectives)
 
   # Renaming vars here to stick to the notation in the paper
   # number of decision variables in the last group (see x_m in the paper)
@@ -49,7 +50,7 @@ makeDTLZ1Function = function(dimensions, n.objectives) {
 
   # C++ implementation
   fn = function(x) {
-    assertNumeric(x, len = dimensions, any.missing = FALSE, all.missing = FALSE)
+    checkNumericInput(x, dimensions)
     dtlz_1(x, M)
   }
 
@@ -75,7 +76,7 @@ makeDTLZ1Function = function(dimensions, n.objectives) {
     id = paste0("dtlz1_", dimensions, "d_", n.objectives, "o"),
     description = "Deb et al.",
     fn = fn,
-    par.set =  makeNumericParamSet(
+    par.set =  ParamHelpers::makeNumericParamSet(
       len = dimensions,
       id = "x",
       #FIXME: any box constraints?
