@@ -1,8 +1,9 @@
 #' @title
 #' MMF1 Function
+#' @encoding UTF-8
 #'
 #' @description
-#' Test problem from the set of "multimodal multiobjective functions" as for
+#' Test problem from the set of "multi-modal multi-objective functions" as for
 #' instance used in the CEC2019 competition.
 #' 
 #' @references
@@ -10,13 +11,14 @@
 #' scalable test problem suite for multimodal multiobjective optimization," in
 #' Swarm and Evolutionary Computation, Volume 48, August 2019, pp. 62–71, Elsevier.
 #' @return [\code{smoof_multi_objective_function}]
+#'  Returns an instance of the MMF1 function as a \code{smoof_multi_objective_function} object.
 #' @export
 makeMMF1Function = function() {
 
   # C implementation
   fn = function(x) {
-    assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE, finite = TRUE)
-    return(mof_cec2019_mmf1(x = x))
+    checkNumericInput(x, 2L)
+    mof_cec2019_mmf1(x = x)
   }
 
   n.objectives = 2L
@@ -25,7 +27,7 @@ makeMMF1Function = function() {
     id = sprintf("MMF1-%id-%io", 2L, n.objectives),
     description = "MMF1 function",
     fn = fn,
-    par.set =  makeNumericParamSet(
+    par.set =  ParamHelpers::makeNumericParamSet(
       len = 2L,
       id = "x",
       lower = c(1, -1),
