@@ -1,21 +1,23 @@
 #' @title
 #' MMF2 Function
+#' @encoding UTF-8
 #'
 #' @description
-#' Test problem from the set of "multimodal multiobjective functions" as for
+#' Test problem from the set of "multi-modal multi-objective functions" as for
 #' instance used in the CEC2019 competition.
 #' 
 #' @references
 #' Caitong Yue, Boyang Qu, Kunjie Yu, Jing Liang, and Xiaodong Li, "A novel
-#' scalable test problem suite for multimodal multiobjective optimization," in
+#' scalable test problem suite for multi-modal multi-objective optimization," in
 #' Swarm and Evolutionary Computation, Volume 48, August 2019, pp. 62–71, Elsevier.
 #' @return [\code{smoof_multi_objective_function}]
+#'  Returns an instance of the MMF2 function as a \code{smoof_multi_objective_function} object.
 #' @export
 makeMMF2Function = function() {
   # C implementation
   fn = function(x) {
-    assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE, finite = TRUE)
-    return(mof_cec2019_mmf2(x = x))
+    checkNumericInput(x, 2L)
+    mof_cec2019_mmf2(x = x)
   }
 
   n.objectives = 2L
@@ -24,7 +26,7 @@ makeMMF2Function = function() {
     id = sprintf("MMF2-%id-%io", 2L, n.objectives),
     description = "MMF2 function",
     fn = fn,
-    par.set =  makeNumericParamSet(
+    par.set =  ParamHelpers::makeNumericParamSet(
       len = 2L,
       id = "x",
       lower = rep(0, 2),
