@@ -1,5 +1,6 @@
 #' @title
 #' MMF13 Function
+#' @encoding UTF-8
 #'
 #' @description
 #' Test problem from the set of "multimodal multiobjective functions" as for
@@ -11,12 +12,13 @@
 #' Swarm and Evolutionary Computation, Volume 48, August 2019, pp. 62–71, Elsevier.
 #'
 #' @return [\code{smoof_multi_objective_function}]
+#'  Returns an instance of the Omni function as a \code{smoof_multi_objective_function} object.
 #' @export
 makeOmniTestFunction = function() {
   # C implementation
   fn = function(x) {
-    assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE, finite = TRUE)
-    return(mof_cec2019_OMNI_Test(x = x))
+    checkNumericInput(x, 2L)
+    mof_cec2019_OMNI_Test(x = x)
   }
 
   n.objectives = 2L
@@ -25,7 +27,7 @@ makeOmniTestFunction = function() {
     id = sprintf("Omni-test-%id-%io", 2L, n.objectives),
     description = "Omni test function",
     fn = fn,
-    par.set =  makeNumericParamSet(
+    par.set =  ParamHelpers::makeNumericParamSet(
       len = 2L,
       id = "x",
       lower = rep(0, 2L),
