@@ -11,20 +11,21 @@
 #' \deqn{g(\mathbf{x}) = 1 + \frac{9}{m - 1} \sum_{i = 2}^m \mathbf{x}_i, h(f_1, g) = 1 - \sqrt{\frac{f_1}{g}}}
 #' and \eqn{\mathbf{x}_i \in [0,1], i = 1, \ldots, m}
 #'
-#' @references E. Zitzler, K. Deb, and L. Thiele. Comparison of Multiobjective
+#' @references E. Zitzler, K. Deb, and L. Thiele. Comparison of Multi-objective
 #' Evolutionary Algorithms: Empirical Results. Evolutionary Computation, 8(2):173-195, 2000
 #'
 #' @param dimensions [\code{integer(1)}]\cr
 #'   Number of decision variables.
 #' @return [\code{smoof_multi_objective_function}]
+#'  Returns an instance of the ZDT1 function as a \code{smoof_multi_objective_function} object.
 #' @export
 makeZDT1Function = function(dimensions) {
-  assertInt(dimensions, lower = 2L)
+  checkmate::assertInt(dimensions, lower = 2L)
   force(dimensions)
 
   # define the two-objective ZDT1 function
   fn = function(x) {
-    assertNumeric(x, len = dimensions, any.missing = FALSE, all.missing = FALSE)
+    checkNumericInput(x, dimensions)
     n = length(x)
     f1 = x[1]
     g = 1 + 9 * sum(x[2:n]) / (n - 1)
@@ -38,7 +39,7 @@ makeZDT1Function = function(dimensions) {
     id = paste0("zdt1_", dimensions, "d_2o"),
     description = "Zitzler et al. function N. 1",
     fn = fn,
-    par.set =  makeNumericParamSet(
+    par.set =  ParamHelpers::makeNumericParamSet(
       len = dimensions,
       id = "x",
       lower = rep(0, dimensions),
