@@ -1,11 +1,16 @@
+#' @title
 #' Ackley Function
 #'
+#' @description
 #' Also known as \dQuote{Ackley's Path Function}.
-#' Multimodal test function with its global optimum in the center of the defintion
+#' Multi-modal test function with its global optimum in the center of the definition
 #' space. The implementation is based on the formula
 #' \deqn{f(\mathbf{x}) = -a \cdot \exp\left(-b \cdot \sqrt{\left(\frac{1}{n} \sum_{i=1}^{n} \mathbf{x}_i\right)}\right) - \exp\left(\frac{1}{n} \sum_{i=1}^{n} \cos(c \cdot \mathbf{x}_i)\right),}
 #' with \eqn{a = 20}, \eqn{b = 0.2} and \eqn{c = 2\pi}. The feasible region is
 #' given by the box constraints \eqn{\mathbf{x}_i \in [-32.768, 32.768]}.
+#' 
+#' @return
+#' An object of class \code{SingleObjectiveFunction}, representing the Ackley Function.
 #'
 #' @references Ackley, D. H.: A connectionist machine for genetic hillclimbing.
 #' Boston: Kluwer Academic Publishers, 1987.
@@ -14,13 +19,13 @@
 #' @template ret_smoof_single
 #' @export
 makeAckleyFunction = function(dimensions) {
-  assertCount(dimensions)
+  checkmate::assertCount(dimensions)
   force(dimensions)
   makeSingleObjectiveFunction(
     name = paste(dimensions, "-d Ackley Function", sep = ""),
     id = paste0("ackley_", dimensions, "d"),
     fn = function(x) {
-      assertNumeric(x, len = dimensions, any.missing = FALSE, all.missing = FALSE)
+      checkNumericInput(x, dimensions)
       n = length(x)
       a = 20
       b = 0.2
@@ -29,7 +34,7 @@ makeAckleyFunction = function(dimensions) {
       e = mean(cos(c * x))
       -a * exp(-b * sqrt(d)) - exp(e) + a + exp(1)
     },
-    par.set = makeNumericParamSet(
+    par.set = ParamHelpers::makeNumericParamSet(
       len = dimensions,
       id = "x",
       lower = -32.768,
