@@ -1,8 +1,13 @@
+#' @title
 #' Bent-Cigar Function
 #'
+#' @description
 #' Scalable test function \eqn{f} with
 #' \deqn{f(\mathbf{x}) = x_1^2 + 10^6 \sum_{i = 2}^{n} x_i^2}
 #' subject to \eqn{-100 \leq \mathbf{x}_i \leq 100} for \eqn{i = 1, \ldots, n}.
+#' 
+#' @return
+#' An object of class \code{SingleObjectiveFunction}, representing the Bent-Cigar Function.
 #'
 #' @references See \url{https://al-roomi.org/benchmarks/unconstrained/n-dimensions/164-bent-cigar-function}.
 #'
@@ -10,16 +15,16 @@
 #' @template ret_smoof_single
 #' @export
 makeBentCigarFunction = function(dimensions) {
-  assertCount(dimensions)
+  checkmate::assertCount(dimensions)
   force(dimensions)
   makeSingleObjectiveFunction(
     name = "Bent-Cigar Function",
     id = "bentCigar_2d",
     fn = function(x) {
-      assertNumeric(x, len = dimensions, any.missing = FALSE, all.missing = FALSE)
+      checkNumericInput(x, dimensions)
       x[1]^2 + 1e+06 * sum(x[2:dimensions]^2)
     },
-    par.set = makeNumericParamSet(
+    par.set = ParamHelpers::makeNumericParamSet(
       len = dimensions,
       id = "x",
       lower = rep(-100, dimensions),
