@@ -1,8 +1,13 @@
+#' @title
 #' Bukin function N. 4
-#'
-#' Second continous Bukin function test function. The formula is given by
+#' 
+#' @description
+#' Second continuous Bukin function test function. The formula is given by
 #' \deqn{f(\mathbf{x}) = 100 \mathbf{x}_2^2 + 0.01 * ||\mathbf{x}_1 +10||}
 #' and the box constraints \eqn{mathbf{x}_1 \in [-15, 5], \mathbf{x}_2 \in [-3, 3]}.
+#' 
+#' @return
+#' An object of class \code{SingleObjectiveFunction}, representing the Bukin N.4 Function.
 #'
 #' @references Z. K. Silagadze, Finding Two-Dimesnional Peaks, Physics of Particles
 #' and Nuclei Letters, vol. 4, no. 1, pp. 73-80, 2007.
@@ -16,10 +21,10 @@ makeBukinN4Function = function() {
     name = "Bukin Function N. 4",
     id = "bukin04_2d",
     fn = function(x) {
-      assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
+      checkNumericInput(x, 2L)
       100 * x[2]^2 + 0.01 * abs(x[1] + 10)
     },
-    par.set = makeNumericParamSet(
+    par.set = ParamHelpers::makeNumericParamSet(
       len = 2L,
       id = "x",
       lower = c(-15, -3),
