@@ -1,11 +1,16 @@
+#' @title
 #' Bukin function N. 6
 #'
+#' @description
 #' Beside Bukin N. 2 and N. 4 this is the last \dQuote{Bukin family} function.
 #' It is given by the formula
 #' \deqn{f(\mathbf{x}) = 100 \sqrt{||\mathbf{x}_2 - 0.01 \mathbf{x}_1^2||} + 0.01 ||\mathbf{x}_1 + 10||}
 #' and the box constraints \eqn{mathbf{x}_1 \in [-15, 5], \mathbf{x}_2 \in [-3, 3]}.
+#' 
+#' @return
+#' An object of class \code{SingleObjectiveFunction}, representing the Bukin N.6 Function.
 #'
-#' @references Z. K. Silagadze, Finding Two-Dimesnional Peaks, Physics of Particles
+#' @references Z. K. Silagadze, Finding Two-Dimensional Peaks, Physics of Particles
 #' and Nuclei Letters, vol. 4, no. 1, pp. 73-80, 2007.
 #'
 #' @seealso \code{\link{makeBukinN2Function}}, \code{\link{makeBukinN4Function}}
@@ -17,10 +22,10 @@ makeBukinN6Function = function() {
     name = "Bukin Function N.6",
     id = "bukin06_2d",
     fn = function(x) {
-      assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
+      checkNumericInput(x, 2L)
       100 * sqrt(abs(x[2] - 0.01 * x[1]^2)) + 0.01 * abs(x[1] + 10)
     },
-    par.set = makeNumericParamSet(
+    par.set = ParamHelpers::makeNumericParamSet(
       len = 2L,
       id = "x",
       lower = c(-15, -3),
