@@ -1,8 +1,11 @@
-#' @title Complex function.
+#' @title Complex function
 #'
 #' @description Two-dimensional test function based on the formula
 #' \deqn{f(\mathbf{x}) = (x_1^3 - 3 x_1 x_2^2 - 1)^2 + (3 x_2 x_1^2 - x_2^3)^2}
 #' with \eqn{\mathbf{x}_1, \mathbf{x}_2 \in [-2, 2]}.
+#' 
+#' @return
+#' An object of class \code{SingleObjectiveFunction}, representing the Complex Function.
 #'
 #' @references See \url{https://al-roomi.org/benchmarks/unconstrained/2-dimensions/43-complex-function}.
 #'
@@ -13,10 +16,10 @@ makeComplexFunction = function() {
     name = "Complex Function",
     id = paste0("complex_2d"),
     fn = function(x) {
-      assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
+      checkNumericInput(x, 2L)
       (x[1]^3 - 3 * x[1] * x[2]^2 - 1)^2 + (3 * x[2] * x[1]^2 - x[2]^3)^2
     },
-    par.set = makeNumericParamSet(
+    par.set = ParamHelpers::makeNumericParamSet(
       len = 2L,
       id = "x",
       lower = c(-2, -2),
