@@ -1,8 +1,13 @@
+#' @title
 #' Cube Function
-#'
+#' 
+#' @description
 #' The Cube Function is defined as follows:
 #' \deqn{f(\mathbf{x}) = 100 (\mathbf{x}_2 - \mathbf{x}_1^3)^2 + (1 - \mathbf{x}_1)^2.}
 #' The box-constraints are given by \eqn{\mathbf{x}_i \in [-10, 10], i = 1, 2.}
+#' 
+#' @return
+#' An object of class \code{SingleObjectiveFunction}, representing the Cube Function.
 #'
 #' @references A. Lavi, T. P. Vogel (eds), Recent Advances in Optimization
 #' Techniques, John Wliley & Sons, 1966.
@@ -14,10 +19,10 @@ makeCubeFunction = function() {
     name = "Cube Function",
     id = "cube_2d",
     fn = function(x) {
-      assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
+      checkNumericInput(x, 2L)
       100 * (x[2] - x[1]^3)^2 + (1 - x[1])^2
     },
-    par.set = makeNumericParamSet(
+    par.set = ParamHelpers::makeNumericParamSet(
       len = 2L,
       id = "x",
       lower = c(-10, -10),
