@@ -1,8 +1,13 @@
+#' @title
 #' Double-Sum Function
 #'
+#' @description
 #' Also known as the rotated hyper-ellipsoid function. The formula is given by
 #' \deqn{f(\mathbf{x}) = \sum_{i=1}^n \left( \sum_{j=1}^{i} \mathbf{x}_j \right)^2}
 #' with \eqn{\mathbf{x}_i \in [-65.536, 65.536], i = 1, \ldots, n}.
+#' 
+#' @return
+#' An object of class \code{SingleObjectiveFunction}, representing the Double-Sum Function.
 #'
 #' @references H.-P. Schwefel. Evolution and Optimum Seeking.
 #' John Wiley & Sons, New York, 1995.
@@ -11,17 +16,17 @@
 #' @template ret_smoof_single
 #' @export
 makeDoubleSumFunction = function(dimensions) {
-  assertCount(dimensions)
+  checkmate::assertCount(dimensions)
   force(dimensions)
   makeSingleObjectiveFunction(
     name = paste(dimensions, "-d Double-Sum Function", sep = ""),
     id = paste0("doubleSum_", dimensions, "d"),
     fn = function(x) {
-      assertNumeric(x, len = dimensions, any.missing = FALSE, all.missing = FALSE)
+      checkNumericInput(x, dimensions)
       # this is faster than the soobench C implementation
       sum(cumsum(x)^2)
     },
-    par.set = makeNumericParamSet(
+    par.set = ParamHelpers::makeNumericParamSet(
       len = dimensions,
       id = "x",
       lower = rep(-65.536, dimensions),
