@@ -1,8 +1,13 @@
+#' @title
 #' Freudenstein Roth Function
 #'
+#' @description
 #' This test function is based on the formula
 #' \deqn{f(\mathbf{x}) = (\mathbf{x}_1 - 13 + ((5 - \mathbf{x}_2)\mathbf{x}_2 - 2)\mathbf{x}_2)^2 + (\mathbf{x}_1 - 29 + ((\mathbf{x}_2 + 1)\mathbf{x}_2 - 14)\mathbf{x}_2)^2}
 #' subject to \eqn{\mathbf{x}_i \in [-10, 10], i = 1, 2}.
+#' 
+#' @return
+#' An object of class \code{SingleObjectiveFunction}, representing the Freundstein-Roth Function.
 #'
 #' @references S. S. Rao, Engineering Optimization: Theory and Practice,
 #' John Wiley & Sons, 2009.
@@ -14,10 +19,10 @@ makeFreudensteinRothFunction = function() {
     name = "Freudenstein Roth Function",
     id = "freudensteinRoth_2d",
     fn = function(x) {
-      assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
+      checkNumericInput(x, 2L)
       (x[1] - 13 + ((5 - x[2]) * x[2] - 2) * x[2])^2 + (x[1] - 29 + ((x[2] + 1) * x[2] - 14) * x[2])^2
     },
-    par.set = makeNumericParamSet(
+    par.set = ParamHelpers::makeNumericParamSet(
       len = 2L,
       id = "x",
       lower = c(-10, -10),
