@@ -1,11 +1,16 @@
+#' @title
 #' Price Function N. 1
 #'
-#' Second function by Price. The implementation is based on the defintion
+#' @description
+#' Second function by Price. The implementation is based on the definition
 #' \deqn{f(\mathbf{x}) = (|\mathbf{x}_1| - 5)^2 + (|\mathbf{x}_2 - 5)^2}
 #' subject to \eqn{\mathbf{x}_i \in [-500, 500], i = 1, 2}.
+#' 
+#' @return
+#' An object of class \code{SingleObjectiveFunction}, representing the Price N. 1 Function.
 #'
 #' @references W. L. Price, A Controlled Random Search Procedure for Global
-#' Optimisation, Computer journal, vol. 20, no. 4, pp. 367-370, 1977.
+#' Optimization, Computer journal, vol. 20, no. 4, pp. 367-370, 1977.
 #'
 #' @seealso \code{\link{makePriceN2Function}}, \code{\link{makePriceN4Function}}
 #'
@@ -16,10 +21,10 @@ makePriceN1Function = function() {
     name = "Price Function N. 1",
     id = "price01_2d",
     fn = function(x) {
-      assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
+      checkNumericInput(x, 2L)
       sum((abs(x) - 5)^2)
     },
-    par.set = makeNumericParamSet(
+    par.set = ParamHelpers::makeNumericParamSet(
       len = 2L,
       id = "x",
       lower = c(-500, -500),
