@@ -1,5 +1,7 @@
+#' @title
 #' Rosenbrock Function
 #'
+#' @description
 #' Also known as the \dQuote{De Jong's function 2} or the \dQuote{(Rosenbrock)
 #' banana/valley function} due to its shape. The global optimum is located within
 #' a large flat valley and thus it is hard for optimization algorithms to find it.
@@ -7,6 +9,9 @@
 #' \deqn{f(\mathbf{x}) = \sum_{i=1}^{n-1} 100 \cdot (\mathbf{x}_{i+1} - \mathbf{x}_i^2)^2 + (1 - \mathbf{x}_i)^2.}
 #' The domain is given by the constraints \eqn{\mathbf{x}_i \in [-30, 30], i = 1, \ldots, n}.
 #'
+#' @return
+#' An object of class \code{SingleObjectiveFunction}, representing the Rosenbrock Function.
+#'
 #' @references H. H. Rosenbrock, An Automatic Method for Finding the Greatest or
 #' least Value of a Function, Computer Journal, vol. 3, no. 3, pp. 175-184, 1960.
 #'
@@ -14,17 +19,17 @@
 #' @template ret_smoof_single
 #' @export
 makeRosenbrockFunction = function(dimensions) {
-  assertInt(dimensions, lower = 2)
+  checkmate::assertInt(dimensions, lower = 2)
   force(dimensions)
   makeSingleObjectiveFunction(
     name = paste(dimensions, "-d Rosenbrock Function", sep = ""),
     id = paste0("rosenbrock_", dimensions, "d"),
     fn = function(x) {
-      assertNumeric(x, len = dimensions, any.missing = FALSE, all.missing = FALSE)
+      checkNumericInput(x, dimensions)
       i = seq_len(length(x) - 1L)
       sum(100 * (x[i]^2 - x[i + 1])^2 + (x[i] - 1)^2)
     },
-    par.set = makeNumericParamSet(
+    par.set = ParamHelpers::makeNumericParamSet(
       len = dimensions,
       id = "x",
       lower = rep(-5, dimensions),
