@@ -1,8 +1,13 @@
+#' @title
 #' Schaffer Function N. 4
-#'
-#' Second function by Schaffer. The defintion is given by the formula
+#' 
+#' @description
+#' Second function by Schaffer. The definition is given by the formula
 #' \deqn{f(\mathbf{x}) = 0.5 + \frac{\cos^2(sin(|\mathbf{x}_1^2 - \mathbf{x}_2^2|)) - 0.5}{(1 + 0.001(\mathbf{x}_1^2 + \mathbf{x}_2^2))^2}}
 #' subject to \eqn{\mathbf{x}_i \in [-100, 100], i = 1, 2}.
+#' 
+#' @return
+#' An object of class \code{SingleObjectiveFunction}, representing the Schaffer N. 4 Function.
 #'
 #' @references S. K. Mishra, Some New Test Functions For Global Optimization
 #' And Performance of Repulsive Particle Swarm Method.
@@ -14,12 +19,12 @@ makeSchafferN4Function = function() {
     name = "Schaffer Function N. 4",
     id = "schaffer04_2d",
     fn = function(x) {
-      assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
+      checkNumericInput(x, 2L)
       a = x[1]^2
       b = x[2]^2
       0.5 + (cos(sin(abs(a - b)))^2 - 0.5) / (1 + 0.001 * (a + b))^2
     },
-    par.set = makeNumericParamSet(
+    par.set = ParamHelpers::makeNumericParamSet(
       len = 2L,
       id = "x",
       lower = c(-100, -100),
