@@ -1,9 +1,14 @@
+#' @title
 #' Sphere Function
 #'
+#' @description
 #' Also known as the the \dQuote{De Jong function 1}. Convex, continous function
 #' calculated via the formula
 #' \deqn{f(\mathbf{x}) = \sum_{i=1}^{n} \mathbf{x}_i^2}
-#' with box-constraings \eqn{\mathbf{x}_i \in [-5.12, 5.12], i = 1, \ldots, n}.
+#' with box-constraints \eqn{\mathbf{x}_i \in [-5.12, 5.12], i = 1, \ldots, n}.
+#' 
+#' @return
+#' An object of class \code{SingleObjectiveFunction}, representing the Sphere Function.
 #'
 #' @references M. A. Schumer, K. Steiglitz, Adaptive Step Size Random Search,
 #' IEEE Transactions on Automatic Control. vol. 13, no. 3, pp. 270-276, 1968.
@@ -18,7 +23,7 @@ makeSphereFunction = function(dimensions) {
     name = paste(dimensions, "-d Sphere Function", sep = ""),
     id = paste0("sphere_", dimensions, "d"),
     fn = function(x) {
-      assertNumeric(x, len = dimensions, any.missing = FALSE, all.missing = FALSE)
+      checkNumericInput(x, dimensions)
       sum(x^2)
     },
     par.set = makeNumericParamSet(
