@@ -1,8 +1,13 @@
+#' @title
 #' Styblinkski-Tang function
 #'
-#' This function is based on the defintion
+#' @description
+#' This function is based on the definition
 #' \deqn{f(\mathbf{x}) = \frac{1}{2} \sum_{i = 1}^{2} (\mathbf{x}_i^4 - 16 \mathbf{x}_i^2 + 5\mathbf{x}_i)}
 #' with box-constraints given by \eqn{\mathbf{x}_i \in [-5, 5], i = 1, 2}.
+#' 
+#' @return
+#' An object of class \code{SingleObjectiveFunction}, representing the Styblinkski-Tang Function.
 #'
 #' @references Z. K. Silagadze, Finding Two-Dimesnional Peaks, Physics of
 #' Particles and Nuclei Letters, vol. 4, no. 1, pp. 73-80, 2007.
@@ -15,12 +20,12 @@ makeStyblinkskiTangFunction = function() {
     name = "Styblinkski-Tang Function",
     id = "styblinskiTang_2d",
     fn = function(x) {
-      assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
+      checkNumericInput(x, 2L)
       a = x^2
       b = a^2
       return(0.5 * sum(b - 16 * a + 5 * x))
     },
-    par.set = makeNumericParamSet(
+    par.set = ParamHelpers::makeNumericParamSet(
       len = 2L,
       id = "x",
       lower = rep(-5, 2L),
