@@ -1,8 +1,13 @@
+#' @title
 #' Zettl Function
 #'
-#' The unimodal Zettl Function is based on the defintion
+#' @description
+#' The uni-modal Zettl Function is based on the definition
 #' \deqn{f(\mathbf{x}) = (\mathbf{x}_1^2 + \mathbf{x}_2^2 - 2\mathbf{x}_1)^2 + 0.25 \mathbf{x}_1}
 #' with box-constraints \eqn{\mathbf{x}_i \in [-5, 10], i = 1, 2}.
+#' 
+#' @return
+#' An object of class \code{SingleObjectiveFunction}, representing the Zettl Function.
 #'
 #' @references H. P. Schwefel, Evolution and Optimum Seeking, John Wiley Sons, 1995.
 #'
@@ -13,10 +18,10 @@ makeZettlFunction = function() {
     name = "Zettl Function",
     id = "zettl_2d",
     fn = function(x) {
-      assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
+      checkNumericInput(x, 2L)
       (x[1]^2 + x[2]^2 - 2 * x[1])^2 + 0.25 * x[1]
     },
-    par.set = makeNumericParamSet(
+    par.set = ParamHelpers::makeNumericParamSet(
       len = 2L,
       id = "x",
       lower = c(-5, -5),
