@@ -1,4 +1,4 @@
-#' Checks whether constraints are violated.
+#' Checks whether constraints are violated
 #'
 #' @template arg_smoof_function
 #' @param values [\code{numeric}]\cr
@@ -6,7 +6,7 @@
 #' @return [\code{logical(1)}]
 #' @export
 violatesConstraints = function(fn, values) {
-  assertClass(fn, "smoof_function")
+  checkmate::assertClass(fn, "smoof_function")
   if (hasOtherConstraints(fn)) {
     constraint.fn = attr(fn, "constraint.fn")
     return(!all(constraint.fn(values)))
